var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });

// src/adapter/node.ts
import { fileURLToPath } from "node:url";
import { basename } from "node:path";
import { fileTypeFromStream } from "file-type";
import { createReadStream } from "node:fs";
import { Readable } from "node:stream";
import { lookup } from "node:dns/promises";
async function fetchFile(url, init) {
  try {
    const stream = Readable.toWeb(createReadStream(fileURLToPath(url)));
    const result = await fileTypeFromStream(stream);
    return new Response(stream, {
      status: 200,
      statusText: "OK",
      headers: {
        "Content-Type": result?.mime || "application/octet-stream",
        "Content-Disposition": `attachment; filename*=UTF-8''${encodeURIComponent(basename(url.pathname))}`
      }
    });
  } catch (error) {
    if (error?.code === "ENOENT" || error?.code === "ENOTDIR") {
      return new Response(null, { status: 404, statusText: "Not Found" });
    } else if (error?.code === "EACCES" || error?.code === "EPERM") {
      return new Response(null, { status: 403, statusText: "Forbidden" });
    } else if (error?.code === "ENAMETOOLONG") {
      return new Response(null, { status: 414, statusText: "URI Too Long" });
    }
    return new Response(null, { status: 500, statusText: "Internal Server Error" });
  }
}
__name(fetchFile, "fetchFile");
export {
  fetchFile,
  lookup
};
